merlin.pcvl\_pytorch.locirc\_to\_tensor module
==============================================

.. automodule:: merlin.pcvl_pytorch.locirc_to_tensor
   :members:
   :undoc-members:
   :show-inheritance:
